@@ -8,7 +8,8 @@ echo "::endgroup::"
 export PATH="$PATH:/opt/python/cp36-cp36m/bin:/opt/python/cp37-cp37m/bin:/opt/python/cp38-cp38/bin:/opt/python/cp39-cp39/bin"
 echo "::group::Install maturin"
 curl -L https://github.com/PyO3/maturin/releases/latest/download/maturin-x86_64-unknown-linux-musl.tar.gz | tar -xz -C /usr/local/bin
-maturin --version
+maturin --version || true
+which patchelf > /dev/null || python3 -m pip install patchelf
 echo "::endgroup::"
 echo "::group::Install Rust target"
 if [[ ! -d $(rustc --print target-libdir --target i686-unknown-linux-gnu) ]]; then rustup target add i686-unknown-linux-gnu; fi
