@@ -15,7 +15,7 @@ pub struct GoPro {
 }
 
 impl GoPro {
-    pub fn detect(buffer: &[u8], _filename: &str) -> Option<Self> {
+    pub fn detect<P: AsRef<std::path::Path>>(buffer: &[u8], _filepath: P) -> Option<Self> {
         let mut ret = None;
     
         if let Some(pos) = memmem::find(buffer, b"GPMFDEVC") {
@@ -58,7 +58,7 @@ impl GoPro {
         if let Some(extra) = &self.extra_gpmf {
             samples.push(SampleInfo { index: 0, timestamp_ms: 0.0, duration_ms: 0.0, tag_map: Some(extra.clone()) });
         }
-        util::get_metadata_track_samples(stream, size, |mut info: SampleInfo, data: &[u8]| {
+        let ctx = util::get_metadata_track_samples(stream, size, |mut info: SampleInfo, data: &[u8]| {
             if Self::detect_metadata(data) {
                 if let Ok(mut map) = GoPro::parse_metadata(&data[8..], GroupId::Default, false) {
                     self.process_map(&mut map);
@@ -67,7 +67,11 @@ impl GoPro {
                 }
             }
         })?;
-        self.process_samples(&mut samples);
+        let mut fps = None;
+        if !ctx.tracks.is_empty() {
+            fps = util::get_fps_from_track(&ctx.tracks[0]);
+        }
+        self.process_samples(&mut samples, fps);
         Ok(samples)
     }
 
@@ -152,22 +156,29 @@ impl GoPro {
         }
     }
 
-    fn process_samples(&self, samples: &mut Vec<SampleInfo>) {
-        fn get_timestamp(info: &util::SampleInfo) -> Option<i64> {
-            if let Some(ref grouped_tag_map) = info.tag_map {
-                for (group, map) in grouped_tag_map {
-                    if group == &GroupId::CameraOrientation || group == &GroupId::ImageOrientation {
-                        let timestamp_us = *(map.get_t(TagId::TimestampUs) as Option<&u64>).unwrap_or(&0) as i64;
-                        return Some(timestamp_us);
+    fn get_timestamp(info: &util::SampleInfo, group_id: &GroupId) -> Option<i64> {
+        if let Some(ref grouped_tag_map) = info.tag_map {
+            for (group, map) in grouped_tag_map {
+                if group == group_id {
+                    let mut tick = 0i64;
+                    if let Some(t) = map.get_t(TagId::Unknown(0x5449434b /*TICK*/)) as Option<&u32> {
+                        tick = (*t as i64) * 1000;
                     }
+                    let timestamp_us = (map.get_t(TagId::TimestampUs) as Option<&u64>).map(|x| *x as i64).unwrap_or(tick);
+                    return Some(timestamp_us);
                 }
             }
-            None
         }
-        
+        None
+    }
+
+    fn process_samples(&self, samples: &mut Vec<SampleInfo>, fps: Option<f64>) {
         // Normalize quaternions
         let mut prev_increment = 0;
         let mut start_timestamp_us = None;
+        let mut global_ts_cori: f64 = 0.0;
+        let mut global_ts_iori: f64 = 0.0;
+        let global_increment = fps.map(|x| 1000.0 / x);
         for i in 0..samples.len() {
             let info = &samples[i];
             if info.tag_map.is_none() { continue; }
@@ -181,7 +192,7 @@ impl GoPro {
                     let scale = *(map.get_t(TagId::Scale) as Option<&i16>).unwrap_or(&32767) as f64;
                     let mut timestamp_us = *(map.get_t(TagId::TimestampUs) as Option<&u64>).unwrap_or(&0) as i64;
                     // let start_count = *(map.get_t(TagId::Count) as Option<&u32>).unwrap_or(&0);
-                    let next_timestamp_us = samples.get(i + 1).map(get_timestamp).unwrap_or(None);
+                    let next_timestamp_us = samples.get(i + 1).map(|x | Self::get_timestamp(x, &group)).unwrap_or(None);
                     if start_timestamp_us.is_none() {
                         start_timestamp_us = Some(timestamp_us);
                     }
@@ -191,9 +202,19 @@ impl GoPro {
                         let increment = next_timestamp_us.map(|x| ((x - timestamp_us) / sample_count)).unwrap_or(prev_increment);
                         prev_increment = increment;
                         for v in arr.iter() {
+                            let mut ts = timestamp_us - start_timestamp_us.unwrap();
+                            if let Some(global_inc) = global_increment {
+                                if group == &GroupId::CameraOrientation {
+                                    ts = (global_ts_cori * 1000.0).round() as i64;
+                                    global_ts_cori += global_inc;
+                                } else {
+                                    ts = (global_ts_iori * 1000.0).round() as i64;
+                                    global_ts_iori += global_inc;
+                                }
+                            }
                             let aout = if group == &GroupId::CameraOrientation { &mut cori } else { &mut iori };
                             aout.push((
-                                timestamp_us - start_timestamp_us.unwrap(), 
+                                ts, 
                                 Quaternion {
                                     w: v.w as f64 / scale, 
                                     x: -v.x as f64 / scale,
@@ -218,6 +239,46 @@ impl GoPro {
             }
         }
     }
+    pub fn get_avg_sample_duration(samples: &Vec<SampleInfo>, group_id: &GroupId) -> Option<f64> {
+        let mut total_duration_ms = 0.0;
+
+        let mut first_tsus = None;
+        let mut last_tsus = None;
+        let mut count = 0;
+        let mut last_len = 0;
+        for info in samples {
+            total_duration_ms += info.duration_ms;
+            if info.tag_map.is_none() { continue; }
+            for (group, map) in info.tag_map.as_ref().unwrap() {
+                if group == group_id {
+                    if let Some(t) = map.get_t(TagId::TimestampUs) as Option<&u64> {
+                        if first_tsus.is_none() { first_tsus = Some(*t as i64); }
+                        last_tsus = Some(*t as i64);
+                    } else if let Some(t) = map.get_t(TagId::TimestampMs) as Option<&u64> {
+                        if first_tsus.is_none() { first_tsus = Some((*t as i64) * 1000); }
+                        last_tsus = Some((*t as i64) * 1000);
+                    } else if let Some(t) = map.get_t(TagId::Unknown(0x5449434b /*TICK*/)) as Option<&u32> {
+                        if first_tsus.is_none() { first_tsus = Some((*t as i64) * 1000); }
+                        last_tsus = Some((*t as i64) * 1000);
+                    }
+                    if let Some(t) = map.get_t(TagId::Data) as Option<&Vec<Vector3<i16>>> {
+                        count += t.len();
+                        last_len = t.len();
+                    } else if let Some(t) = map.get_t(TagId::Data) as Option<&Vec<Quaternion<i16>>> {
+                        count += t.len();
+                        last_len = t.len();
+                    }
+                }
+            }
+        }
+        if first_tsus.is_some() && last_tsus.is_some() && count > 0 {
+            Some((last_tsus.unwrap() as f64 - first_tsus.unwrap() as f64) / (count - last_len).max(1) as f64 / 1000.0)
+        } else if count > 0 {
+            Some(total_duration_ms / count as f64)
+        } else {
+            None
+        }
+    }
 
     fn get_last_klv(data: &[u8]) -> Result<&[u8]> {
         let mut slice = Cursor::new(data);
