@@ -21,7 +21,7 @@ pub struct Insta360 {
 }
 
 impl Insta360 {
-    pub fn detect(buffer: &[u8], _filename: &str) -> Option<Self> {
+    pub fn detect<P: AsRef<std::path::Path>>(buffer: &[u8], _filepath: P) -> Option<Self> {
         if buffer.len() > MAGIC.len() && &buffer[buffer.len()-MAGIC.len()..] == MAGIC {
             return Some(Insta360::default());
         }
@@ -77,9 +77,11 @@ impl Insta360 {
         }
     
         let imu_orientation = match self.model.as_deref() {
-            Some("Insta360 GO 2") => "yXZ",
-            Some("Insta360 OneR") => "yXZ",
-            _                     => "yXZ"
+            Some("Insta360 Go")    => "xyZ",
+            Some("Insta360 GO 2")  => "yXZ",
+            Some("Insta360 OneR")  => "yXZ",
+            Some("Insta360 OneRS") => "yxz",
+            _                      => "yXZ"
         };
     
         if let Some(x) = tag_map.get_mut(&GroupId::Gyroscope) {
