@@ -1,11 +1,13 @@
 mod sony;
 mod gopro;
+mod gyroflow;
 mod insta360;
 mod blackbox;
 mod runcam;
 mod witmotion;
 mod dji;
 mod phone_apps;
+mod ardupilot;
 
 pub mod tags_impl;
 pub mod util;
@@ -23,10 +25,13 @@ macro_rules! impl_formats {
             pub samples: Option<Vec<SampleInfo>>
         }
         impl Input {
-            pub fn from_stream<T: Read + Seek>(stream: &mut T, size: usize, filename: &str) -> Result<Input> {
+            pub fn from_stream<T: Read + Seek, P: AsRef<std::path::Path>>(stream: &mut T, size: usize, filepath: P) -> Result<Input> {
                 let buf = util::read_beginning_and_end(stream, size, 2*1024*1024)?; // 2 MB
+                if buf.is_empty() {
+                    return Err(Error::new(ErrorKind::Other, "File is empty or there was an error trying to load it."));
+                }
                 $(
-                    if let Some(mut x) = <$class>::detect(&buf, filename) {
+                    if let Some(mut x) = <$class>::detect(&buf, &filepath) {
                         return Ok(Input {
                             samples: x.parse(stream, size).ok(),
                             inner: SupportedFormats::$name(x)
@@ -57,10 +62,12 @@ macro_rules! impl_formats {
 impl_formats! {
     GoPro     => gopro::GoPro,
     Sony      => sony::Sony,
+    Gyroflow  => gyroflow::Gyroflow,
     Insta360  => insta360::Insta360,
     BlackBox  => blackbox::BlackBox,
     Runcam    => runcam::Runcam,
     WitMotion => witmotion::WitMotion,
     Dji       => dji::Dji,
     PhoneApps => phone_apps::PhoneApps,
+    ArduPilot => ardupilot::ArduPilot,
 }
