@@ -13,7 +13,7 @@ pub struct WitMotion {
 }
 
 impl WitMotion {
-    pub fn detect(buffer: &[u8], _filename: &str) -> Option<Self> {
+    pub fn detect<P: AsRef<std::path::Path>>(buffer: &[u8], _filepath: P) -> Option<Self> {
         if buffer.len() > 11 && buffer[0..2] == [0x55, 0x50] && buffer[11] == 0x55 {
             return Some(Self { txt: false, model: None });
         }
